=========================
Oscar 0.6.3 release notes
=========================

This is Oscar 0.6.3.  It fixes a few issues that have been discovered since the
latest release.

Known issues
============

* Django 1.4 only: The changes in `#1127`_ mean you explicitly need to register
  a call to ``migrate_alerts_to_users`` when the ``post_save`` signal is
  emitted for a ``User`` model.

Bug fixes
=========

The following issues were fixed:

* Several strings have been marked translatable.

* `#1167`_ - Offers without ranges can be created correctly.

* `#1166`_, `#1176`_ - Migrations work again with custom User model.

* `#1186`_ - Fix bug with dashboard order search

.. _`#1127`: https://github.com/django-oscar/django-oscar/issues/1127
.. _`#1166`: https://github.com/django-oscar/django-oscar/issues/1166
.. _`#1167`: https://github.com/django-oscar/django-oscar/issues/1167
.. _`#1176`: https://github.com/django-oscar/django-oscar/issues/1176
.. _`#1186`: https://github.com/django-oscar/django-oscar/issues/1186
